import {HttpException, HttpStatus, Injectable} from "@nestjs/common";
import {InjectRepository} from "@nestjs/typeorm";
import {Constants} from "src/utils/constants";
import {ResponseUtils} from "src/utils/response.utils";
import {UploadedMulterFileI} from "src/modules/SpacesModule/SpacesService";
import {DoSpacesService} from "src/modules/SpacesModule/SpacesService/doSpacesService";
import { ClearenceSaleSectionCmsRepository } from "./clearence-sale-section-cms.repository";
import { UpdateClearenceSaleSectionCmsDto } from "./dto/update-clearence-sale-section-cms.dto";
import { ClearenceSaleSectionCmsEntity } from "./entities/clearence-sale-section-cms.entity";

@Injectable()
export class ClearenceSaleSectionCmsService {
    constructor(
        @InjectRepository(ClearenceSaleSectionCmsRepository)
        private readonly repository: ClearenceSaleSectionCmsRepository,
        private readonly doSpaceService: DoSpacesService
    ) {
    }

    async updateOrCreateData(
        dto: UpdateClearenceSaleSectionCmsDto,
        files: {
            leftSideImage: UploadedMulterFileI,
        }
    ): Promise<ClearenceSaleSectionCmsEntity | Error> {
        if (files && files.leftSideImage) {
            const leftSideImage: any = await this.doSpaceService.uploadFile(files.leftSideImage[0], "ClearenceSaleSectionCms/");
            dto.leftSideImage = leftSideImage;
        }
        const isExists = await this.repository.find({isDeleted: false});
        if (Object.keys(isExists).length === 0) {
            const data = await this.repository.createEntity(dto);
            if (!data) {
                throw new HttpException(
                    Constants.NOT_FOUND,
                    HttpStatus.NOT_FOUND
                );
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            let id = isExists[0].id;
            const data = await this.repository.updateEntity(dto, id);
            if (!data) {
                throw new HttpException(
                    Constants.UPDATE_FAILED,
                    HttpStatus.BAD_REQUEST
                );
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<ClearenceSaleSectionCmsEntity[] | Error> {
        const data = await this.repository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}