import {EntityRepository, getConnection, Repository} from "typeorm";
import { CollectionPageEntity } from "./entities/collection-page.entity";
import { CreateCollectionPageDto } from "./dto/create-collection-page.dto";
import { UpdateCollectionPageDto } from "./dto/update-collection-page.dto";

@EntityRepository(CollectionPageEntity)
export class CollectionPageRepository extends Repository<CollectionPageEntity> {
    async createEntity(dto: CreateCollectionPageDto): Promise<CollectionPageEntity | Error> {
        try {
            const {
                title,
                subtitle,
                description,
                buttonLink,
                buttonText,
                image,
            } = dto;
            const entity = this.create({
                title,
                subtitle,
                description,
                buttonLink,
                buttonText,
                image
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<CollectionPageEntity | Error> {
        try {
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdateCollectionPageDto): Promise<CollectionPageEntity | Error> {
        try {
            await this.update(id, {
                title: dto.title,
                subtitle: dto.subtitle,
                description: dto.description,
                buttonLink: dto.buttonLink,
                buttonText: dto.buttonText,
                image: dto.image,
            });
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<CollectionPageEntity[] | Error> {
        try {
            return await this.find({
                where: {...query, isDeleted: false}
            });
        } catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(CollectionPageEntity)
                .set({isDeleted: true})
                .where("id = :id", {id: id})
                .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        } catch (e) {
            return e;
        }
    }
}