import {EntityRepository, getConnection, Repository} from "typeorm";
import {CreateFAQDto} from "./dto/create-faq.dto";
import {UpdateFAQDto} from "./dto/update-faq.dto";
import {FAQ} from "./entities/faq.entity";

@EntityRepository(FAQ)
export class FAQRepository extends Repository<FAQ> {
    async createEntity(dto: CreateFAQDto): Promise<FAQ | Error> {
        try {
            const {
                question,
                answer
            } = dto;
            const entity = this.create({
                question,
                answer
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<FAQ | Error> {
        try {
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdateFAQDto): Promise<FAQ | Error> {
        try {
            await this.update(id, {
                question: dto.question,
                answer: dto.answer
            });
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<FAQ[] | Error> {
        try {
            return await this.find({
                where: {...query, isDeleted: false}
            });
        } catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(FAQ)
                .set({isDeleted: true})
                .where("id = :id", {id: id})
                .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        } catch (e) {
            return e;
        }
    }
}