import {HttpException, HttpStatus, Injectable} from "@nestjs/common";
import {InjectRepository} from "@nestjs/typeorm";
import {Constants} from "src/utils/constants";
import {ResponseUtils} from "src/utils/response.utils";
import {UploadedMulterFileI} from "../../SpacesModule/SpacesService";
import {DoSpacesService} from "../../SpacesModule/SpacesService/doSpacesService";
import {CreateSocialMediaLinkDto} from "./dto/create-social-media-link.dto";
import {SocialMediaLinkEntity} from "./entities/social-media-link.entity";
import {UpdateSocialMediaLinkDto} from "./dto/update-social-media-link.dto";
import {SocialMediaLinkRepository} from "./social-media-link.repository";

@Injectable()
export class SocialMediaLinkService {
    constructor(
        @InjectRepository(SocialMediaLinkRepository)
        private readonly repository: SocialMediaLinkRepository,
        private readonly doSpaceService: DoSpacesService
    ) {
    }

    async create(
        dto: CreateSocialMediaLinkDto,
        files: {
            logo: UploadedMulterFileI
        }
    ): Promise<SocialMediaLinkEntity | Error> {
        if (files && files.logo) {
            const logo: any = await this.doSpaceService.uploadFile(files.logo[0], "SocialMediaLink/");
            dto.logo = logo;
        }
        const data = await this.repository.createEntity(dto);
        if (!data) {
            throw new HttpException(
                Constants.CREATE_FAILED,
                HttpStatus.BAD_REQUEST
            );
        }
        return ResponseUtils.successResponseHandler(201, "Data created successfully", "data", data);
    }

    async findAll(): Promise<SocialMediaLinkEntity[] | Error> {
        const data = await this.repository.findByFilterQuery({});
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }

    async findOne(id: string): Promise<SocialMediaLinkEntity[] | Error> {
        const data = await this.repository.findByFilterQuery({id: id});
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }

    async remove(id: string): Promise<boolean | Error> {
        const data = await this.repository.deleteEntity(id);
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.buildDeletedData(data, 200, "Data deleted successfully");
    }

    async update(
        id: string,
        dto: UpdateSocialMediaLinkDto,
        files: {
            logo: UploadedMulterFileI
        }): Promise<SocialMediaLinkEntity | Error> {
        const res: any = await this.repository.findOneEntity(id);
        if (!res) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }

        if (files && files.logo) {
            const logo: any = await this.doSpaceService.uploadFile(files.logo[0], "SocialMediaLink/");
            dto.logo = logo;
        }
        const data = await this.repository.updateEntity(id, dto);
        if (!data) {
            throw new HttpException(
                Constants.UPDATE_FAILED,
                HttpStatus.BAD_REQUEST
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data updated successfully", "data", data);
    }
}
