import { EntityRepository, getConnection, Repository } from "typeorm";
import { CreateCouponDto } from "./dto/create-coupon.dto";
import { UpdateCouponDto } from "./dto/update-coupon.dto";
import { Coupon } from "./entity/coupon.entity";

@EntityRepository(Coupon)
export class CouponRepository extends Repository<Coupon> {
    async createEntity(
        dto: CreateCouponDto
    ): Promise<Coupon | Error> {
        try {
            const { couponCode, couponName, couponType, discount, expireDate } = dto;
            const entity = this.create({
                couponCode,
                couponName,
                couponType,
                discount,
                expireDate
            });
            await this.save(entity);
            return entity;
        }
        catch (e) {
            return e;
        }
    }

    async findOneEntity(
        id: string
    ): Promise<Coupon | Error> {
        try {
            return await this.findOne(id);
        }
        catch (e) {
            return e;
        }
    }

    async updateEntity(
        id: string,
        dto: UpdateCouponDto
    ): Promise<Coupon | Error> {
        try {
            await this.update(id, {
                couponCode: dto.couponCode,
                couponName : dto.couponName,
                couponType : dto.couponType,
                discount : dto.discount,
                expireDate : dto.expireDate
            });
            return await this.findOne(id);
        }
        catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query : any): Promise<any | Error> {
        try {
            return await this.find({
                where: { ...query, isDeleted: false }
            });
        }
        catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(Coupon)
                .set({ isDeleted: true })
                .where("id = :id", { id: id })
                .execute();
            if(updateResult.affected > 0) {
                return true;
            }
            return false;
        }
        catch(e) {
            return e;
        }
    }

    async getCouponDiscountByCouponNumber (couponNumber : string, orderTotal : any) {
        try {
            let couponDiscount = 0;
            if (!couponNumber) {
                return false;
            }
            const couponInfo = await this.findOne({where: {couponCode: couponNumber, isDeleted: false}}); 
            if (Object.keys(couponInfo).length <= 0 ) {
                return false;
            } 
            if (couponInfo.couponType === "fixed") couponDiscount = parseInt(couponInfo.discount);
            else if (couponInfo.couponType === "percent") {
                let newCouponDiscount = orderTotal * (parseInt(couponInfo.discount) /100);
                couponDiscount = Number((newCouponDiscount.toFixed(2)));
            }
            else if (couponInfo.couponType === "onetime") {
                if(couponInfo.cuponUsedTotal >= 1) {
                    return false;
                }
                else {
                    couponDiscount = parseInt(couponInfo.discount);
                }
            }
            else if (couponInfo.couponType === "welcome"){
                let newCouponDiscount = orderTotal * (parseInt(couponInfo.discount) /100);
                couponDiscount = Number((newCouponDiscount.toFixed(2)));
            }
            return couponDiscount;
        } catch (err) {
            return err;
        }
    }
}