import { Controller, Get, Post, Body, Patch, Param, Delete } from '@nestjs/common';
import { ReturnProductsService } from './return-products.service';
import { CreateReturnProductAdminDto } from './dto/create-return-product-admin.dto';
import { UpdateReturnProductDto } from './dto/update-return-product.dto';
import { Constants } from 'src/utils/constants';
import { Query, UseGuards } from '@nestjs/common/decorators';
import { AuthGuard } from 'src/core/guards/auth.guard';
import { AdminAuthGuard } from 'src/core/guards/admin-auth.guard';
import { stat } from 'fs';
import { CreateReturnProductDto } from './dto/create-return-product.dto';

@Controller({
  path: 'return-products',
  version: Constants.API_VERSION_1
})
export class ReturnProductsController {
  constructor(private readonly returnProductsService: ReturnProductsService) {}

  @Post('/bulk-status-update')
  @UseGuards(AdminAuthGuard)
  bulkStatusUpdate(@Body() dto: any) {
    return this.returnProductsService.bulkStatusUpdate(dto);
  }

  @Post('/admin-return')
  @UseGuards(AuthGuard)
  adminReturn(@Body() dto: CreateReturnProductAdminDto) {
    return this.returnProductsService.adminReturn(dto);
  }

  @Post()
  @UseGuards(AuthGuard)
  create(@Body() createReturnProductDto: CreateReturnProductDto) {
    return this.returnProductsService.create(createReturnProductDto);
  }

  @Get()
  @UseGuards(AdminAuthGuard)
  findAll(
    @Query('status') status: string
  ) {
    return this.returnProductsService.findAll(status);
  }

  @Get('/filter-by-orderid/:id')
  @UseGuards(AuthGuard)
  filterByOrderId(@Param('id') id: string) {
    return this.returnProductsService.filterByOrderId(id);
  }

  @Get(':id')
  @UseGuards(AuthGuard)
  findOne(@Param('id') id: string) {
    return this.returnProductsService.findOne(id);
  }


  @Patch(':id')
  @UseGuards(AdminAuthGuard)
  update(@Param('id') id: string, @Body() dto: UpdateReturnProductDto) {
    return this.returnProductsService.update(id, dto);
  }

  @Delete(':id')
  @UseGuards(AdminAuthGuard)
  remove(@Param('id') id: string) {
    return this.returnProductsService.remove(id);
  }
}
