import {Body, Controller, Delete, Get, Param, Patch, Post, UseGuards} from '@nestjs/common';
import {Constants} from 'src/utils/constants';
import {ShippingMethodsService} from './shipping-method.service';
import {CreateShippingMethodsDto} from './dto/create-shipping-method.dto';
import {UpdateShippingMethodsDto} from './dto/update-shipping-method.dto';
import {AdminAuthGuard} from 'src/core/guards/admin-auth.guard';

@Controller({path: 'shipping-methods', version: Constants.API_VERSION_1})

export class ShippingMethodsController {
    constructor(private readonly service: ShippingMethodsService) {
    }

    @Post()
    @UseGuards(AdminAuthGuard)
    create(@Body() dto: CreateShippingMethodsDto) {
        return this.service.create(dto);
    }

    @Get()
    // @UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }

    @Get(':id')
    @UseGuards(AdminAuthGuard)
    findOne(@Param('id') id: string) {
        return this.service.findOne(id);
    }

    @Patch('/:id')
    @UseGuards(AdminAuthGuard)
    update(@Param('id') id: string, @Body() dto: UpdateShippingMethodsDto) {
        return this.service.update(id, dto);
    }

    @Delete(':id')
    @UseGuards(AdminAuthGuard)
    async remove(@Param('id') id: string) {
        return await this.service.remove(id);
    }
}
